@@ -6,7 +6,6 @@
 #' @param cheight the height of the canvas element
 #' @param cfill the color of the canvas element. Default to #FFFFFF (white)
 #' @param drawingWidth the width of the drawing output. Default to 2
-#' @param drawingColor the color of the drawing output. Default to #1E1E1E (black)
 #' @param gumSize specify the size of the gum. Defaults to 10
 #'
 #' @return an HTML canvas element
@@ -17,7 +16,6 @@
 #'
 #'ui <- fluidPage(
 #'
-#'    use_fabric(),
 #'
 #'    h1("Draw some stuff here"),
 #'
@@ -39,7 +37,6 @@ fabric_drawing <- function(cid,
                           cheight = 600,
                           cfill = "#FFFFFF",
                           drawingWidth = 2,
-                          drawingColor = "#1E1E1E",
                           gumSize = 10){
 
 
@@ -47,17 +44,24 @@ fabric_drawing <- function(cid,
 htmltools::tagList(
 
 
-  htmltools::tags$input(id=glue::glue("erase{cid}"), type="checkbox", " Gum"),
+  htmltools::HTML(glue::glue("
 
-  htmltools::tags$input(id=glue::glue("export{cid}"), type="button", value = "Export"),
+  <input id = erase{cid} type = 'checkbox' title='Check it to erase !'>
 
-  htmltools::tags$br(),  htmltools::tags$br(),
+  <input id = {cid}drawing-color type = 'color' value = '#005E7A' style = 'width:30px;'>
+
+  <input id = export{cid} type = 'button' style = 'width:55px;' value = 'Export'>
+
+                             ")),
 
   htmltools::tags$canvas(id = cid, width = cwidth, height = cheight),
 
-  htmltools::tags$script(src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"),
+  fabric_dependency(),
+
+  filesaver_dependency(),
+
+  jquery_dependency(),
 
-  htmltools::tags$script(src="https://cdn.jsdelivr.net/npm/file-saver@2.0.2/dist/FileSaver.min.js"),
 
   htmltools::tags$script(htmltools::HTML(glue::glue(
     "
@@ -72,8 +76,13 @@ const {cid} = new fabric.Canvas('{cid}', {{
 {cid}.freeDrawingBrush.width  = {drawingWidth};
 
 
-{cid}.freeDrawingBrush.color  = '{drawingColor}';
+{cid}drawingColorEl = document.getElementById('{cid}drawing-color');
 
+{cid}.freeDrawingBrush.color = {cid}drawingColorEl.value;
+
+{cid}drawingColorEl.onchange = function() {{
+    {cid}.freeDrawingBrush.color = {cid}drawingColorEl.value;
+  }};
 
 
  $('#erase{cid}').click(function(){{
@@ -84,7 +93,7 @@ const {cid} = new fabric.Canvas('{cid}', {{
 
     }} else {{
 
-      {cid}.freeDrawingBrush.color = '{drawingColor}';
+      {cid}.freeDrawingBrush.color = {cid}drawingColorEl.value;
 
     }}
 
@@ -126,6 +135,10 @@ $('#export{cid}').click(function(){{
 
 
 
+
+
+
+
   "
   )))
 
