@@ -20,8 +20,8 @@
 #' @param selectable logical. If TRUE, the user can modify interactively the shape's size, position and rotation. Defaults to TRUE
 #' @param isDrawingMode logical. If TRUE, the user can draw inside the canvas element.
 #' @param radius mandatory if the chosen shape is a 'Circle'. Defaults to NULL
-#' @param polx a vector of the coordinate points of the polygon, from the left.
-#' @param poly a vector of the coordinate points of the polygon, from the top
+#' @param xPolygon a vector of the coordinate points of the polygon, from the left.
+#' @param yPolygon a vector of the coordinate points of the polygon, from the top
 #'
 #' @return a shape object inside a canvas
 #' @export
@@ -32,7 +32,6 @@
 #'
 #'ui <- fluidPage(
 #'
-#'use_fabric(),
 #'
 #'h2("Below you'll find a red Rectangle with a darkblue stroke"),
 #'
@@ -73,8 +72,8 @@ fabric_shape <- function(cid,
                          selectable = TRUE,
                          isDrawingMode = FALSE,
                          radius = NULL,
-                         polx = NULL,
-                         poly = NULL) {
+                         xPolygon = NULL,
+                         yPolygon = NULL) {
 
   if (!shape %in% c("Rect",
                     "Circle",
@@ -85,27 +84,27 @@ fabric_shape <- function(cid,
 
 
   if (shape == "Polygon" &
-      is.null(poly) & is.null(polx)) {
-    stop("If you draw a Circle, you need to provide a radius")
+      is.null(yPolygon) & is.null(xPolygon)) {
+    stop("If you draw a Polygon, you need to se the xPolygon and yPolygon arguments")
   }
 
   if (shape == "Polygon" &
-      is.null(polx)) {
-    stop("If you draw a Circle, you need to provide a radius")
+      is.null(xPolygon)) {
+    stop("If you draw a Circle, you need to set the xPolygon argument")
   }
 
   if (shape == "Polygon" &
-      is.null(poly)) {
-    stop("If you draw a Circle, you need to provide a radius")
+      is.null(yPolygon)) {
+    stop("If you draw a Circle, you need to set the yPolygon argument")
   }
 
   if (shape == "Polygon" &
 
-      length(polx) != length(poly)
+      length(xPolygon) != length(yPolygon)
 
   ){
 
-    stop("polx and poly must have the same length")
+    stop("xPolygon and yPolygon must have the same length")
 
   }
 
@@ -126,7 +125,7 @@ fabric_shape <- function(cid,
   if(shape == "Polygon"){
 
 
-  data <- paste("{x:", polx, ", y:", poly, "}", collapse = ",")
+  data <- paste("{x:", xPolygon, ", y:", yPolygon, "}", collapse = ",")
 
 
     htmltools::tagList(
@@ -136,6 +135,9 @@ fabric_shape <- function(cid,
         height = cheight
       ),
 
+      fabric_dependency(),
+
+
       htmltools::tags$script(htmltools::HTML(
         glue::glue(
           "
@@ -152,8 +154,16 @@ var {shapeId} = new fabric.{shape}(
 
 [{data}], {{
 
-fill: '{fill}'
-
+fill: '{fill}',
+left: {left},
+top: {top},
+width: {width},
+height: {height},
+angle: {angle},
+opacity: {opacity},
+stroke: '{strokecolor}',
+strokeWidth: {strokewidth},
+selectable: {selectable}
 
 }});
 
@@ -181,6 +191,9 @@ fill: '{fill}'
         height = cheight
       ),
 
+      fabric_dependency(),
+
+
 htmltools::tags$script(htmltools::HTML(
         glue::glue(
           "
